==> gearmand_1.1.18+ds.orig.tar.xz: gearmand-1.1.18/libgearman-server/struct/thread.h <==
/*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 * 
 *  Gearmand client and server library.
 *
 *  Copyright (C) 2011 Data Differential, http://datadifferential.com/
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *
 *      * Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *      * Redistributions in binary form must reproduce the above
 *  copyright notice, this list of conditions and the following disclaimer
 *  in the documentation and/or other materials provided with the
 *  distribution.
 *
 *      * The names of its contributors may not be used to endorse or
 *  promote products derived from this software without specific prior
 *  written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#pragma once

#include <pthread.h>

struct gearman_server_thread_st
{
  uint32_t con_count;
  uint32_t io_count;
  uint32_t proc_count;
  uint32_t to_be_freed_count;
  uint32_t free_con_count;
  uint32_t free_packet_count;
  gearmand_connection_list_st *gearman;
  gearman_server_thread_st *next;
  gearman_server_thread_st *prev;
  gearman_log_server_fn *log_fn;
  gearmand_thread_st *log_context;
  gearman_server_thread_run_fn *run_fn;
  void *run_fn_arg;
  gearman_server_con_st *con_list;
  gearman_server_con_st *io_list;
  gearman_server_con_st *proc_list;
  gearman_server_con_st *free_con_list;
  gearman_server_con_st *to_be_freed_list;
  gearman_server_packet_st *free_packet_list;
  gearmand_connection_list_st gearmand_connection_list_static;
  pthread_mutex_t lock;

  void run(gearman_server_thread_run_fn *run_fn_, void *run_fn_arg_)
  {
    run_fn= run_fn_;
    run_fn_arg= run_fn_arg_;
  }
};

==> gearmand_1.1.19.1+ds.orig.tar.xz: gearmand-1.1.19.1/libgearman-server/struct/thread.h <==
/*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 * 
 *  Gearmand client and server library.
 *
 *  Copyright (C) 2011 Data Differential, http://datadifferential.com/
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *
 *      * Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *      * Redistributions in binary form must reproduce the above
 *  copyright notice, this list of conditions and the following disclaimer
 *  in the documentation and/or other materials provided with the
 *  distribution.
 *
 *      * The names of its contributors may not be used to endorse or
 *  promote products derived from this software without specific prior
 *  written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#pragma once

#include <pthread.h>

struct gearman_server_thread_st
{
  uint32_t con_count{};
  uint32_t io_count{};
  uint32_t proc_count{};
  uint32_t to_be_freed_count{};
  uint32_t free_con_count{};
  uint32_t free_packet_count{};
  gearmand_connection_list_st *gearman{nullptr};
  gearman_server_thread_st *next{nullptr};
  gearman_server_thread_st *prev{nullptr};
  gearman_log_server_fn *log_fn{nullptr};
  gearmand_thread_st *log_context{nullptr};
  gearman_server_thread_run_fn *run_fn{nullptr};
  void *run_fn_arg{nullptr};
  gearman_server_con_st *con_list{nullptr};
  gearman_server_con_st *io_list{nullptr};
  gearman_server_con_st *proc_list{nullptr};
  gearman_server_con_st *free_con_list{nullptr};
  gearman_server_con_st *to_be_freed_list{nullptr};
  gearman_server_packet_st *free_packet_list{nullptr};
  gearmand_connection_list_st gearmand_connection_list_static{};
  pthread_mutex_t lock;

  void run(gearman_server_thread_run_fn *run_fn_, void *run_fn_arg_)
  {
    run_fn= run_fn_;
    run_fn_arg= run_fn_arg_;
  }
};
